Solar Flare Data Base (Data Set #2)

# Info on Solar Flare Data Base (Data Set #2)

    1. TItle: Solar Flare database

    2. Source Information
       -- Donor: Gary Bradshaw
       -- Date: 3/89

    3. Past Usage:
       -- Gary Bradshaw: (Class Attributes were collapsed to 0 and >0)
       -- See the past-usage file for a note written by Gary Bradshaw

    4. Relevant Information:
       -- The database contains 3 potential classes, one for the number of times a
          certain type of solar flare occured in a 24 hour period.
       -- Each instance represents captured features for 1 active region on the
          sun.
       -- The data are divided into two sections. The second section (flare.data2)
          has had much more error correction applied to the it, and has
          consequently been treated as more reliable.

    5. Number of Instances:  flare.data1: 323, flare.data2: 1066

    6. Number of attributes:  13 (includes 3 class attributes)

    7. Attribute Information:
       1. Code for class (modified Zurich class)  (A,B,C,D,E,F,H)
       2. Code for largest spot size              (X,R,S,A,H,K)
       3. Code for spot distribution              (X,O,I,C)
       4. Activity                                (1 = reduced, 2 = unchanged)
       5. Evolution                               (1 = decay, 2 = no growth,
                                                   3 = growth)
       6. Previous 24 hour flare activity code    (1 = nothing as big as an M1,
                                                   2 = one M1,
                                                   3 = more activity than one M1)
       7. Historically-complex                    (1 = Yes, 2 = No)
       8. Did region become historically complex  (1 = yes, 2 = no)
          on this pass across the sun's disk
       9. Area                                    (1 = small, 2 = large)
      10. Area of the largest spot                (1 = <=5, 2 = >5)

     From all these predictors three classes of flares are predicted, which are
     represented in the last three columns.

      11. C-class flares production by this region    Number
          in the following 24 hours (common flares)
      12. M-class flares production by this region    Number
          in the following 24 hours (moderate flares)
      13. X-class flares production by this region    Number
          in the following 24 hours (severe flares)

    8. Missing values: None

    9. Class Distribution:

       flare.data1:
                        0   1  2  4 Total
       C-class flares 287  29  7  0 323
       M-class flares 291  24  6  2 323
       X-class flares 316   7  0  0 323

       flare.data2:

                        0    1  2  3  4  5  6  7  8  Total
       C-class flares  884 112 33 20  9  4  3  0  1  1066
       M-class flares 1030  29  3  2  1  0  1  0  0  1066
       X-class flares 1061   4  1  0  0  0  0  0  0  1066